# IrisCTF 2025 - "Shake My Hand" Walkthrough 
This is an interactive Python writeup and walkthrough for the "Shake My Hand" 2025 Iris CTF challenge.

## Features
- Step-by-step TCP handshake demonstration
- Real-time packet crafting and analysis with Scapy
- ASCII art interface

## Requirements
- Python 3.x
- Scapy library (pip install scapy)
- Windows/Linux compatible

## Install/run with PIP
1. Install with "pip install shakemyhand-walkthrough"
2. Enter "shakemyhand-walkthrough" at terminal.

## Manual install/run
Download shakemyhand-walkthrough.py, make sure you have scapy installed (pip install scapy) and run the file with "python ./shakemyhand-walkthrough.py"
